@@ -7,16 +7,18 @@ use warnings;
 =head1 NAME
 
 CLI::Files::Utils - Extra CLI utilies for handling file bunches.
-'dirhier', 'madeafter' and 'colorplus -3' -- Utilize them after mastering "ls -l" and "find .".
+'dirhier' and 'madeafter' -- Utilize them after mastering "ls -l" and "find .".
+
+Other CLI utilities are also provided : 'colorplus', 'timeput', 'microsec'
 
 
 =head1 VERSION
 
-Version 0.105
+Version 0.11
 
 =cut
 
-our $VERSION = '0.105';
+our $VERSION = '0.11';
 
 
 =head1 SUPPORT
